require(gplots)
require(igraph)

############################################################
### Run simulation
############################################################
distributions <- c("rand", "split", "local", "regional") # possible clearing patterns


run.reps<-function(distributions, # vecotr of possible clearing patterns
                   compliances, # vector of possible compliance levels 
                   n.reps, # number of repetitions
                   init.comp, # initial compliance level -- proportion of total landscape native habitat
                   init.dist, # initial distribution of clearing 
                   n.property.sides, # number of parcels along each edge of each square property
                   target, # legal compliance level
                   n.hab, # number of types of habitats in landscape
                   p.deforest, # probability that a parcel that can legally be deforested is deforested
                   alpha, Beta, # parameters that aggregate the profitability of the landscape (see Appendix) 
                   res, # indicator variable for reserve: 0=no reserve, 1=reserve
                   profit.corr, # indicator variable for habitat to be correlated with agricultural profit: 0=not correlated, 1=correlated
                   phi) # strength of correlation between habitat type and ag profit (see Appendix)
{
  tic<-proc.time()
  result<-indiv.result<-array(NA,c(length(distributions),length(compliances),10,n.reps),
                              dimnames=list(distributions, compliances, NULL,NULL))#c('ben','prod','prod.prop'),NULL))
  for (i in 1:length(distributions))
  {
    for (j in 1:length(compliances))
    {
      print (i)
      
      init.dist<-distributions[i]
      init.comp<-compliances[j]
      
      temp<-main.code(n.reps, init.comp, init.dist, n.property.sides, target, n.habs, p.deforest, alpha, Beta, res, res.sides, profit.corr, phi)
      indiv.result[i,j,1,]<-temp$indiv.ben.changes
      indiv.result[i,j,2,]<-temp$indiv.prod.changes
      indiv.result[i,j,3,]<-temp$indiv.prod.prop.changes
      indiv.result[i,j,4,]<-temp$indiv.mean.csize.changes
      indiv.result[i,j,5,]<-temp$indiv.min.csize.changes
      indiv.result[i,j,6,]<-temp$indiv.max.csize.changes
      indiv.result[i,j,7,]<-temp$indiv.cnum.changes
      indiv.result[i,j,8,]<-temp$indiv.ea.changes
      indiv.result[i,j,9,]<-temp$indiv.median.csize.changes
      indiv.result[i,j,10,]<-temp$indiv.min.hab.rep.changes
    }
  }
  toc<-proc.time()-tic
  return(list(indiv.result=indiv.result, toc=toc))
}

############################################################
## Generating Results -- running the simulations for different scenarios
############################################################

############################################################
## Main result
############################################################

n.reps<-1000
n.property.sides<-20
target<-0.5
distributions<-c("rand","split","local","regional")
compliances<-0.5#seq(0.25,.5,by=0.25)
p.deforest<-1
n.habs<-1
res<-0

temp<-run.reps(distributions, compliances, n.reps, init.comp, init.dist, n.property.sides, target, n.habs, p.deforest, alpha, Beta, res)
result<-temp$result; indiv.result<-temp$indiv.result; toc<-temp$toc
print(toc/60/60)
indiv.result.habs1<-indiv.result


############################################################
## Testing spatial correlation
############################################################
phiTests <- seq(0.001,0.8, length=8)
p.deforest<-0.5

for (ctr in 1:length(phiTests))
{
  phi<-phiTests[i]
  temp<-run.reps(distributions, compliances, n.reps, init.comp, init.dist, n.property.sides, target, n.habs, p.deforest, alpha, Beta, res,profit.corr,phi)
  print(temp$toc/60/60)
  indiv.result.phi[[i]]<-temp$indiv.result
}

############################################################
## Testing number of habitats
############################################################

n.habs<-4
temp<-run.reps(distributions, compliances, n.reps, init.comp, init.dist, n.property.sides, target, n.habs, p.deforest, alpha, Beta, res,profit.corr,phi)
indiv.result.habs4<-temp$indiv.result

############################################################
## Testing hot air trades 
############################################################

#n.reps<-500
#n.property.sides<-10
#target<-0.5
#distributions<-c("rand","split","local","regional")
#compliances<-0.5#seq(0.25,.5,by=0.25)
n.habs<-1

p.deforest<-0.75
temp<-run.reps(distributions, compliances, n.reps,init.comp, init.dist,  n.property.sides, target, n.habs, p.deforest, alpha, Beta, res)
indiv.075deforest<-indiv.result<-temp$indiv.result

############################################################
## Testing reserve 
############################################################

res<-1 # reserve is included
res.sides<-7 # square root number of parcels in reserve
temp<-run.reps(distributions, compliances, n.reps, init.comp, init.dist, n.property.sides, target, n.habs, p.deforest, alpha, Beta, res)
indiv.result.reserve<-temp$indiv.result


############################################################
## Testing targets 
############################################################

#n.reps<-500
#n.property.sides<-20
#target<-0.5
#distributions<-c("rand","split","local","regional")
#compliances<-0.5#seq(0.25,.5,by=0.25)
n.habs<-1
p.deforest<-1
res<-0

target<-0.25
temp<-run.reps(distributions, compliances, n.reps,init.comp, init.dist,  n.property.sides, target, 
               n.habs, p.deforest, alpha, Bet, res)
indiv.result.t25<-temp$indiv.result

target<-0.75
temp<-run.reps(distributions, compliances, n.reps,init.comp, init.dist,  n.property.sides, target, 
               n.habs, p.deforest, alpha, Bet, res)
indiv.result.t75<-temp$indiv.result

