
n.properties<-n.property.sides^2
n.sides<-n.property.sides*2
n.parcels<-n.sides*n.sides
ag.prod.vect<-rnorm(n.parcels, mean=50, sd=20)
ag.prod<-matrix(ag.prod.vect,ncol=n.sides); ag.prod[which(ag.prod<0)]<-0;

prob.hab<-function(x, Beta)
{
  ph<-Beta+x*(1-2*Beta)/4
  chh<-as.numeric(runif(1)<ph)
  return(chh)
}

sum.nhbs<-function(index, mat, n.sides)
{
  dim(mat)<-c(n.sides, n.sides)
  # convert index to coords
  x<-index%%n.sides; x[which(x==0)]<-n.sides
  y<-ceiling(index/n.sides)
  sumn<-sum(mat[min(x+1,n.sides),y], mat[max(x-1,0),y], mat[x,min(y+1,n.sides)], mat[x,max(y-1,0)])
  return(sumn)
}

#############################################
##  Generating random aggregated landscapes of habitat
#############################################
# lower alpha, more dispersed -- controls the number of iterations used to aggregate the habitat
# Higher Beta, more dispersed (closer to random) -- the likelihood the aggregated habitat is rejected in favour of random

### No correlation with agricultural productivity
gen.habs<-function(alpha, Beta, n.parcels, n.habs)
{
  
  habitats<-rep(0, n.parcels)
  n.sides<-sqrt(n.parcels)
  habitats<-sample(1:n.habs, n.parcels, replace=TRUE)
  ctr=0
  while (ctr<=20)
  {
    n.diff<-n.parcels*alpha # number to initially allocate
    check.change<-sample(1:n.parcels, n.diff) # which parcels to allocate 
    sns<-sapply(check.change, sum.nhbs, habitats, n.sides, n.habs) 
    sns<-rbind(sns, habitats[check.change])
    habitats[check.change]<-apply(sns,2,FUN=prob.hab, Beta)
    ctr<-ctr+1
  }
  ctr1=0
  while (prod((1/n.habs*0.95)*n.parcels <= table(habitats))==0)
  {
    red.hab<-which.max(table(habitats))#which((1/n.habs*1.05)*n.parcels < table(habitats))#sample(which((1/n.habs*1.05)*n.parcels > table(habitats)),1)
    check.change<-sample(which(habitats==red.hab), min(table(habitats)[red.hab]-(1/n.habs)*n.parcels))
    sns<-sapply(check.change, sum.nhbs, habitats, n.sides, n.habs)
    sns<-rbind(sns, habitats[check.change])
    habitats[check.change]<-apply(sns,2,FUN=prob.hab, Beta)
    ctr1=ctr1+1
  }
  return(habitats)
}

### Correlated with ag productivity
gen.habs.profit.corr<-function(alpha, Beta, n.parcels, n.habs, ag.prod)
{
  habitats<-rep(0, n.parcels)
  n.sides<-sqrt(n.parcels)
  n.habs<-n.habs-1
  habitats<-sample(1:n.habs, n.parcels, replace=TRUE)
  ctr=0
  while (ctr<=20)
  {
    n.diff<-n.parcels*alpha # number to initially allocate
    check.change<-sample(1:n.parcels, n.diff) # which parcels to allocate 
    sns<-sapply(check.change, sum.nhbs, habitats, n.sides, n.habs) 
    sns<-rbind(sns, habitats[check.change])
    habitats[check.change]<-apply(sns,2,FUN=prob.hab, Beta)
    ctr<-ctr+1
  }
  ctr1=0
  while (prod((1/n.habs*0.95)*n.parcels <= table(habitats))==0)
  {
    red.hab<-which.max(table(habitats))#which((1/n.habs*1.05)*n.parcels < table(habitats))#sample(which((1/n.habs*1.05)*n.parcels > table(habitats)),1)
    check.change<-sample(which(habitats==red.hab), min(table(habitats)[red.hab]-(1/n.habs)*n.parcels))
    sns<-sapply(check.change, sum.nhbs, habitats, n.sides, n.habs)
    sns<-rbind(sns, habitats[check.change])
    habitats[check.change]<-apply(sns,2,FUN=prob.hab, Beta)
    ctr1=ctr1+1
  }
  n <- length(ag.prod)
  n.low<-round(n*(1-1/(n.habs+1)))
  habitats[which(ag.prod%in%sort(ag.prod,partial=round(n.low))[(n.low):n])]<-n.habs+1
  return(habitats)
}































