require(gplots)
##############################################################
# creating figure 1 -- clumped bar plots of metric performance
##############################################################
par(mar=c(7,6,1,1), mfrow=c(1,2))
layout(mat=matrix(1:2,1), widths=c(1.2,2))
heights<-ci.ls<-ci.us<-tmax<-tmin<-heightsd<-matrix(NA, length(distributions), 10)
for (i in 1:length(distributions))
{
  for (j in 1:10)
  {
    heights[i,j]<-mean(indiv.result[i,1,j,], na.rm=T)
    tmax[i,j]<-max(indiv.result[i,1,j,], na.rm=T)
    ci.ls[i,j]<-quantile(indiv.result[i,1,j,],0.025, na.rm=T)
    ci.us[i,j]<-quantile(indiv.result[i,1,j,],0.975, na.rm=T)
    heightsd[i,j]<-sd(indiv.result[i,1,j,],na.rm=T)/sqrt(n.reps)
  }
}
heights.swap<-heights;heights.swap[2,]<-heights[3,];heights.swap[3,]<-heights[2,]
heights<-heights.swap
distributions.swap<-distributions;distributions.swap[2,]<-distributions[3,];distributions.swap[3,]<-distributions[2,]
distributions<-distributions.swap
main.tit<-c('Probability of \n connectivity', 'Economic \n productivity',
            'Economic \n productivity', 
            'Mean \n fragment size', 'Minimum \n fragment size',
            'Maxmimum \n fragment size', 'Number of \n fragments', 'Edge to area \n ratio', 'Median \n fragment size')
chosen.m<-c(1,6) # which measures we are plotting
upper = heights[,chosen.m]+1.96*heightsd[,chosen.m]
lower = heights[,chosen.m]-1.96*heightsd[,chosen.m]
ymax<-rep(1,10);ymax[1]<-max(1,max(ci.us[,1])); ymax[6]<-max(heightsd[,6])#, 1)#max(ci.us[,6]),1)
ymin<-rep(-1,10); 
barplot2(heights[,chosen.m],beside=TRUE,
         names = main.tit[chosen.m], 
         ylab = "Percentage change \n achieved by allowing trade", 
         col=c("#f6eff7","#bdc9e1","#67a9cf","#02818a"),las=1,ylim=c(0, 25),plot.ci=TRUE, 
         ci.u = upper, ci.l = lower)
chosen.m<-c(3,4,7,8) # which measures we are plotting
upper = heights[,chosen.m]+1.96*heightsd[,chosen.m]
lower = heights[,chosen.m]-1.96*heightsd[,chosen.m]
ymax<-rep(1,10);ymax[1]<-max(1,max(ci.us[,1])); ymax[6]<-max(max(ci.us[,6]))#,1)
ymin<-rep(-1,10); 
barplot2(heights[,chosen.m],beside=TRUE,
         names = main.tit[chosen.m], #horiz=TRUE,
         legend = c("Random", "Split", "Local", "Regional"),
         col=c("#f6eff7","#bdc9e1","#67a9cf","#02818a"),las=1,ylim=c(-1,5),
         plot.ci=TRUE, ci.u = upper, ci.l = lower)

##########################################
## For the rest of the line figures:
#########################################
metrics.base<-height.basesd<-array(NA, dim=c(length(distributions), 10))
for (i in 1:length(distributions))
{
  for (j in 1:10)
  {
    metrics.base[i,j]<-mean(indiv.result.habs1[i,1,j,])
    height.basesd[i,j]<-sd(indiv.result.habs1[i,1,j,])/sqrt(n.reps)
  }
}
orange.plots<-function(metrics.corr, height.corrsd)
{
  require(gplots)
  chosen.m<-c(1,4,6,7,8)#,10)
  upper = metrics.corr+1.96*height.corrsd
  lower = metrics.corr-1.96*height.corrsd
  signific<-sign(upper)==sign(lower)
  cols<-c("#fb6a4a","#ef3b2c","#cb181d","#99000d")
  scenarios<-c("Random", "Split", "Local", "Regional")
  types<-1:length(chosen.m)
  par(mfrow=c(1,3), mar=c(5,5,2,2))
  main.tit<-c('Probability of connectivity', 'Economic productivity',
              'Economic productivity', 
              'Mean fragment size', 'Minimum fragment size',
              'Maxmimum fragment size', 'Number of fragments', 'Edge to area ratio', 'Median fragment size')
  for (dctr in 2:length(distributions))
  {
    plot(metrics.corr[,dctr,chosen.m[1]]*signific[,dctr,chosen.m[1]]/abs(metrics.base[dctr,chosen.m[[1]]]), 
         type='l', lty=types[1], lwd=3, ylim=c(-0.2, 2),
         col=cols[1],xlab='Spatial autocorrelation of productivity', xaxt='n', 
         ylab='Proportion of landscape benefit achieved', main=scenarios[dctr],
         cex.lab=2, cex.axis=2)
    axis(1,at=c(1,6),labels=c('0.001', '0.55'), cex.axis=2)
    for (ctr in 2:length(chosen.m))
    {
      met<-chosen.m[ctr]
      lines((metrics.corr[,dctr,met])*signific[,dctr,met]/abs(metrics.base[dctr,met]), type='l',  
            lty=types[ctr], lwd=3, col=cols[ctr]) 
    }
  }
}

##############################################################
# creating figure 2 -- habitat performance
##############################################################
max.n.habs<-4
metrics.habs<-ci.ls.habs<-ci.us.habs<-height.habssd<-array(NA, dim=c(max.n.habs, length(distributions), 10))
indiv.result.allhabs<-list(indiv.result.habs1,indiv.result.habs2,indiv.result.habs3,indiv.result.habs4)
for (hctr in 1:max.n.habs)
{
  indiv.result<-indiv.result.allhabs[[hctr]]
  for (i in 1:length(distributions))
  {
    for (j in 1:10)
    {
      metrics.habs[hctr,i,j]<-mean(indiv.result[i,1,j,])
      height.habssd[hctr,i,j]<-sd(indiv.result[i,1,j,])/sqrt(n.reps)
    }
  }
}
orange.plots<-function(metrics.habs, height.habssd)
  
##############################################################
# creating figure 3 -- hot air trades
##############################################################
max.n.probs<-5
metrics.probs<-height.probssd<-array(NA, dim=c(max.n.probs, length(distributions), 10))
indiv.result.allprobs<-list(indiv.result.habs1,indiv.075deforest,indiv.050deforest,indiv.025deforest,indiv.0deforest)
for (hctr in 1:max.n.probs)
{
  indiv.result<-indiv.result.allprobs[[hctr]]
  for (i in 1:length(distributions))
  {
    for (j in 1:10)
    {
      metrics.probs[hctr,i,j]<-mean(indiv.result[i,1,j,])
      height.probssd[hctr,i,j]<-sd(indiv.result[i,1,j,])/sqrt(n.reps)
    }
  }
}
orange.plots<-function(metrics.procs, height.probssd)
  
##############################################################
# testing phi
##############################################################

phiTests<-seq(from=0.001, to=0.8, length.out=8)
par(mfrow=c(2,3), mar=c(5,5,2,2))
phiFigs<-c(0.001, 0.05, 0.1, 0.2, 0.3, 0.5)
for(pctr in 1:length(phiFigs[1:6])){
  # Set up distance matrix
  distance <- as.matrix(dist(simgrid))
  # Generate random variable
  phi <- phiFigs[pctr]
  X <- rmvn(1, rep(0, n), exp(-phi * distance))
  require(raster)
  Xraster <- rasterFromXYZ(cbind(simgrid[, 1:2] - 0.5, X))
  ag.prod<-as.matrix(Xraster)
  ag.prod<-ag.prod+abs(min(ag.prod))
  heatmap.2(ag.prod, dendrogram='none', Rowv=FALSE, Colv=FALSE, col=paste("gray",1:99,sep=""), 
            labRow=' ', labCol=' ',trace='none', key=FALSE,lwid = c(0.03,0.2),lhei = c(.03,.2))
}

max.n.corr<-6
metrics.corr<-ci.ls.corr<-ci.us.corr<-height.corrsd<-array(NA, dim=c(max.n.corr, length(distributions), 10))
indiv.result.allcorr<-list(indiv.result.phi0.05,indiv.result.phi0.1,indiv.result.phi0.2,indiv.result.phi0.5,indiv.result.phi0.6,indiv.result.phi0.7)
for (hctr in 1:max.n.corr)
{
  indiv.result<-indiv.result.allcorr[[hctr]]
  for (i in 1:length(distributions))
  {
    for (j in 1:10)
    {
      metrics.corr[hctr,i,j]<-mean(indiv.result[i,1,j,])
      height.corrsd[hctr,i,j]<-sd(indiv.result[i,1,j,])/sqrt(n.reps)
    }
  }
}
